ConsoleColors class

Console logger colors

Constructors

ConsoleColors()
Default console colors
const

Properties

config String
no setter
fine String
no setter
finer String
no setter
finest String
no setter
hashCode int
The hash code for this object.
no setterinherited
info String
no setter
reset String
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severe String
no setter
shout String
no setter
warning String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited