MaskingString class

A class that masks a string by replacing all occurrences of a given string

Annotations

Constructors

MaskingString(String from, {bool caseSensitive = true, String maskedString = _defaultMaskedString, bool isRegExp = false})
Create a MaskingString instance.

Properties

caseSensitive bool
Whether the search for the from string is case sensitive.
final
from String
The string to search for in the source string.
final
hashCode int
The hash code for this object.
no setteroverride
maskedString String
What to replace the from string with.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

mask(String input) String
Mask the input string.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override