AbstractLogger class abstract
An abstract logger
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> - Dispose logger
-
init(
Map< Level, int> retainStrategy) → Future<void> - Init logger
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sessionStart(
) → Future< String?> - Start a new session, it can return string with session id
-
toString(
) → String -
A string representation of this object.
inherited
-
write(
MaskedLogRecord record) → void - Write record
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited